import { InfoBox } from "../components/Boxes";
import { TabButtonRow } from "../components/Buttons";
import Collapsible from "../components/Collapsible";
import { H2} from "../components/headings";
import { LoremMedium, LoremShort } from "../components/loremipsum";
import { Circle } from "../components/Shapes";
import { Complex } from "../components/svgs";
import { ButtonRowTabs } from "../components/Tabs";
/* import PieChart from './Graph.tsx';  */

export function Description() { 
  return (
      <div className="row mt-4">
        <div className="col">
          <div  className="col">
            <section id="Abstract" className="section">
                <H2 text="Abstract"/>
                <p>We are proud to introduce our next-generation prime editing technology <a href="#" className="underline--magical">PreCyse</a>. We aim to develop an innovative gene therapy against cystic fibrosis, tackling the most common mutation ΔF508 of the CFTR (Cystic Fibrosis Transmembrane Conductance Regulator) gene. We optimize lipid nanoparticles for the efficient and cell-specific delivery of our therapeutic mRNA. Current treatment strategies are limited in terms of speed, precision and effectiveness, often failing to achieve long-lasting improvements. In addition, high costs and limited accessibility of pharmaceuticals contribute to adverse prognosis of many patients. We want to develop a monthly applied which represents a cure that is more advanced and user-friendly compared to other medications due to its longer lasting time, lowering the frequency of use. </p>
                </section>
          </div> 

          <div className="col">
            <section id="Cystic Fibrosis" className="section">
                <H2 text="Cystic Fibrosis"/>
                 <h3>General</h3> 
                <div className="row align-items-center">
                    <div className="col">
                        <p data-aos="zoom-y-out" >Cystic fibrosis (CF) is the most common life-limiting genetic disorder in the Caucasian population. In Europe, CF affecting about 1 in 3,000 newborns<a href="#desc-one"><sup>1</sup></a>.</p>
                        <p> It is caused by mutations in the CFTR gene, which controls ions and water movement in cells. This leads to thick mucus, clogging airways, and frequent infections. The defective CFTR protein impacts the respiratory and digestive systems, causing chronic lung infections, breathing difficulties, and malnutrition. CF's severity varies, but it reduces life quality and expectancy. There are over 1,700 CFTR mutations; the ΔF508 mutation is most common, present in 70% of cases. It prevents proper protein folding, affecting its function. </p>
                        <p><LoremMedium/></p>
                    </div>
                    <div className="col-2 "> 
                            <Circle text="1:3000 newborns worldwide"/>
                            <Circle text="x:y newborns in Germany"/>
                            <Circle text="kosten"/>
                    </div>
                    {/* <Linear
                    xAxis={[{ data: [1, 2, 3, 5, 8, 10] }]}
                    series={[
                        {
                        data: [2, 5.5, 2, 8.5, 1.5, 5],
                        },
                    ]}
                    width={500}
                    height={300}
                    />  */}
                </div>
                <div className="col">
                    <img src="https://static.igem.wiki/teams/5247/charts-maps/cfper10-000.png"></img>
                </div>
                <h3>CFTR</h3>
                <div className="row align-items-center">
                    <div className="col-2 "> 
                        <img src="https://static.igem.wiki/teams/5247/placeholders/placehilderperson.jpeg"/> 
                        <img src="https://static.igem.wiki/teams/5247/placeholders/placehilderperson.jpeg"/>
                    </div>
                    <div className="col">
                       <p>Text about CFTR <LoremMedium/></p>
                    </div>
                </div>
                <h3>ΔF508</h3>
                <p>A multitude of mutations in the CFTR gene, exceeding 1,000, are responsible for the development of cystic 
                    fibrosis. The most prevalent variant is F508del, observed in approximately 70% of affected individuals of 
                    Caucasian descent in Canada, Northern Europe, and the United States <a href="#desc-14"><sup>14</sup></a>. It is estimated that around 90% of 
                    the European population and people of European heritage with cystic fibrosis carry at least one F508del 
                    variant <a href="#desc-15"><sup>15,</sup></a><a href="#desc-16"><sup>16</sup></a>. Analyses have demonstrated that the F508del mutation originated in Western Europe at least 
                    5,000 years ago <a href="#desc-15"><sup>15</sup></a>. </p>
                <p>It is a deletion of the three nucleotides "CTT" at position 508, which removes the phenylalanine residue 
                    without causing a frameshift. This deletion leads to defects in the kinetic and thermodynamic folding 
                    of the NBD1 domain <a href="#desc-16"><sup>16</sup></a>. However, this not only leads to misfolding of CFTR but also to defects in 
                    trafficking and premature degradation, resulting in reduced surface expression of CFTR <a href="#desc-17"><sup>17</sup></a>. </p>
            
                <img src="https://static.igem.wiki/teams/5247/charts-maps/cfper10-000.png"/>
                <h3>Symptoms</h3>
                <p>Text about symptoms</p>
                <Collapsible title="How the symptoms affect different parts of the body" ></Collapsible>
                <h3>Diagnosis</h3>
                <p>About the ways one can be diagnosed <LoremMedium/></p> 
                <div className="row align-items-center">
                    <div className="col" >
                        <img src="https://static.igem.wiki/teams/5247/placeholders/placehilderperson.jpeg"/>
                    </div>
                    <div className="col" >
                        How newbornscreening affected the numbers.
                        <LoremMedium/>
                    </div>
                </div>
                 <h3>Treatment</h3> 
                <img src="https://static.igem.wiki/teams/5247/placeholders/placehilderperson.jpeg"/> 
                <Collapsible title="Different types of drugs" >
                <TabButtonRow data={medibuttonrowdata} opentype="meditabs" closing=""/>
                <ButtonRowTabs data={medibuttonrowdata} cla="meditabs"/>
                </Collapsible>
                <p>Why we still need other options</p>
                <img src="https://static.igem.wiki/teams/5247/charts-maps/cfper10-000.png"/> 
            </section>
          </div>

          <div className="col">
            <section id="Our motivation" className="section">
                <H2 text="Our motivation"></H2>
                <p>We chose to focus on CF and specifically the ΔF508 mutation due to its prevalence and the severe impact it has on patients' lives. Additionally, our team includes members who have close friends affected by this condition, giving us a personal connection and a strong motivation to find a solution. By targeting the ΔF508 mutation, we aim to develop a therapy that could potentially, not only benefit many CF patients and make a significant improvement in their lives, but also can serve as a template, which research groups can use to target other genetic diseases. </p>
                <div className="row align-items-center">
                    <div className="col" >
                         </div>
                    <div className="col" >
                        <img className="img" src="https://static.igem.wiki/teams/5247/placeholders/placehilderperson.jpeg"/>
                    </div>    
                </div>
                <p>Max</p> 
            </section>
          </div>

          <div className="col">
            <section id="Approach" className="section">
                <H2 text="Approach"></H2>
                <p>To correct the mutation, we are utilizing Prime Editing technologies. Prime Editing is a genome editing technique that allows precise DNA modifications without causing double-strand breaks<a href="#desc-two"><sup>2</sup></a>. Structurally, the Prime Editing complex consists of a Cas9 endonuclease fused to a reverse transcriptase (RT) and guided by a pegRNA, which directs the complex to the target site in the genome.  </p>
                <InfoBox title="Prime Editing">
                    <details>
                        <summary>Prime editing is a new method of gene editing based on an RNA-Protein complex. It was developed by a group of researchers revolving around Professor David Liu from Harvard University in 2019. <a href="#desc-nine"><sup>9</sup></a></summary>
                        <p>Details</p>
                        <LoremMedium/>
                    </details>
                </InfoBox> 
{/*                 <img className="img-right img-half" src="https://static.igem.wiki/teams/5247/scientific-figures/komplex-komplett-beschriftet.svg"/>    
                */} <div className="img-right img-half"><Complex></Complex></div>
                 
                <div>
                    <p>However, the Prime Editing complex is relatively large, posing challenges for therapeutic delivery<a href="#desc-three"><sup>3</sup></a>. Additionally, Prime Editing has been shown to be relatively inefficient in terms of gene editing rates, which could limit its therapeutic utility<a href="#desc-four"><sup>4</sup></a>. Our project aims to enhance the Prime Editing approach by miniaturizing its components. Fanzor, a recently discovered eukaryotic endonuclease, performs functions similar to Cas9, a crucial part of the Prime Editing complex, but is significantly smaller. We aim to substitute Cas9 with Fanzor. </p>
                    <p>Additionally, we plan to replace the reverse transcriptase in the Prime Editing complex with a smaller RT variant. Furthermore, MCP proteins will be added to the Prime Editing complex to increase its stability<a href="#desc-five"><sup>5</sup></a>.  </p>
                </div>
                 <Collapsible title="Cas vs. Fanzor" ></Collapsible> 
                <p>The pegRNA is optimized via an extension by a stem loop, which stabilizes the RNA by protecting it from RNases and serves as a binding site for the MCP, which also supports the secondary RNA structure. Additionally, the pegRNA contains a riboswitch, a sodium ion-controlled regulator that switches off the complex. This represents a major biosafety feature in that the complex is switched off after successful DNA editing and the subsequent increased influx of chloride ions into the cell. The pegRNA is combined with an optimized sgRNA resulting in higher on-target effect. Overall, its optimization leads to a longer shelf life and an increase in the biosafety of the complex. </p>
                 <InfoBox title="Riboswitch">
                    About the Riboswitch
                </InfoBox> 
            </section>
          </div>

          <div className="col">
            <section id="Delivery" className="section">
                <H2 text="Delivery"></H2>
                <img className="img-left img-half spin" src="https://static.igem.wiki/teams/5247/scientific-figures/lnp.png" height={"200vw"}/>  
                <div>
                    <p>We chose LNPs as the delivery system of our Next-Generation Prime Editing Technology. Because of their large capacity and less immunogenic side effects compared to other delivery systems like Adeno-associated Viruses (AVV)<a href="#desc-six"><sup>6</sup></a>. Our aim is to optimize the LNP formulation to improve delivery to lung tissue via inhalation. Because of our collaborations, we are able to test and optimize different delivery systems to improve our organ specific therapeutic approach. Therefore, our LNP design focusses on stability and targeting. Stability is achieved by a polyethylene glycol (PEG) coating that protects the LNPs from degradation by the immune system<a href="#desc-seven"><sup>7</sup></a>. Moreover, we use capsaicin in combination with chitosan to improve the uptake of our construct through their mucus-adhesive properties<a href="#desc-eight"><sup>8</sup></a>. </p>
                </div>
                <div className="row align-items-center">
                     <div className="col">
                        LAgertemperatur der Parts <LoremShort/>
                    </div>
                    <div className="col">
                        Trocknung <LoremShort/>
                    </div> 
                </div>
                <p>We are furthermore optimising the LNPs for pulmonary therapy and investigating delivery by nebulisation as a non-invasive method compared to systemic approaches to make the therapy more convenient for patients. For specific targeting, we are focussing on marker proteins of basal cells and ionocytes that produce particularly high levels of CFTR protein and which we want to target with appropriate antibodies<a href="#desc-nine"><sup>9</sup></a>. Our workflow includes testing our next generation Prime Editing Technology delivered by our optimized LNPs in cell culture lines but also in primary nasal epithelial cells of CF patients to evaluate our optimizations and further improvements in vitro. We can also provide the outlook on the adaptation of the delivery system enabling systemic applications as well. </p>
            </section>
          </div>

          <div className="col">
            <section id="Our vision" className="section">
                <H2 text="Our vision"></H2>   

                <p>We are envisioning a potential integration into a broader therapeutic framework involving customized gene editing tools for various genetic disorders, that present similar problems/difficulties to the F508del mutation, as well as other genetic diseases of different causes. This could include collaborations with pharmaceutical companies to develop new treatment modalities for genetic diseases beyond cystic fibrosis, utilizing advanced delivery systems and personalized medicine approaches. </p>
                {/* <H2 text="Editing Statistics"/> */}
                {/*  <PieChart />  */} {/* Render the PieChart component */}
            </section>
          </div>
    
        {/* Sources */}
        <div className="col">
        <section id="References">
            <H2 text="References"></H2>    
            <ol>
                {/* <!-- Citation num 1--> */}
                <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-one">
                    <span property="schema:author" typeof="schema:Person">
                        <span property="schema:Name">Scotet, V.</span>,
                        <span property="schema:Name">Gutierrez, H.</span>,
                        <span property="schema:Name">Farrell, P. </span>
                    </span>
                    <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                    <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                    <b property="issueNumber" typeof="PublicationIssue">6</b>,
                    (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                    <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                </li>

                {/* <!-- Citation num 2--> */}
                <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-two">
                    <span property="schema:author" typeof="schema:Person">
                        <span property="schema:Name">Anzalone, A.V.</span>,
                        <span property="schema:Name">Randolph, P.B.</span>,
                        <span property="schema:Name">Davis, J.R.</span>,
                        <span property="schema:Name">Sousa, A.A.</span>,
                        <span property="schema:Name">Koblan, L.W.</span>,
                        <span property="schema:Name">Levy, J.M.</span>,
                        <span property="schema:Name">Newby, G.A.</span>,
                        <span property="schema:Name">Raguram, A.</span>,
                        <span property="schema:Name">Liu, D.R. </span>
                    </span>
                    <span property="schema:name">Search-and-replace genome editing without double-strand breaks or donor DNA. </span>
                    <i property="schema:publisher" typeof="schema:Organization">Nature </i>
                    <b property="issueNumber" typeof="PublicationIssue">574</b>,
                    <span property="schema:pageBegin"> 589</span>-<span property="schema:pageEnd">594 </span>
                     (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2019">2019</time>).
                    <a className="doi" href="https://doi.org/10.1038/s41586-019-1711-4"> doi: 10.1038/s41586-019-1711-4</a>
                </li>

                {/* <!-- Citation num 3--> */}
                <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-three">
                    <span property="schema:author" typeof="schema:Person">
                        <span property="schema:Name">Broad Institute of MIT and Harvard. </span>
                    </span>
                    <span property="schema:name">Researchers engineer in vivo delivery system for prime editing, partially restoring vision in mice. </span>
                    <i property="schema:publisher" typeof="schema:Organization">Phys.org </i>
                    (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2024">2024</time>).
                </li>

                {/* <!-- Citation num 4--> */}
                <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-four">
                    <span property="schema:author" typeof="schema:Person">
                        <span property="schema:Name">Gaudelli, N.</span>,
                        <span property="schema:Name">Komor, A.</span>,
                        <span property="schema:Name">Rees, H.</span>,
                        <span property="schema:Name">Packer, M.</span>,
                        <span property="schema:Name">Badran, A.</span>,
                        <span property="schema:Name">Bryson, D.</span>,
                        <span property="schema:Name">Liu, D. </span>
                    </span>
                    <span property="schema:name">Programmable editing of a target base in genomic DNA without double-stranded DNA cleavage. </span>
                    <i property="schema:publisher" typeof="schema:Organization">Nature </i>
                    <b property="issueNumber" typeof="PublicationIssue">533</b>,
                    <span property="schema:pageBegin"> 420</span>-<span property="schema:pageEnd">424 </span>
                    (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2016">2016</time>). 
                    <a className="doi" href="https://doi.org/10.1038/nature17946"> doi: 10.1038/nature17946</a>
                </li>

                {/* <!-- Citation num 5--> */}
                <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-five">
                    <span property="schema:author" typeof="schema:Person">
                        <span property="schema:Name">OpenEd CUNY. </span>
                    </span>
                    <span property="schema:name">RNA Stability and the Role of RNA-Binding Proteins. </span>
                    <i property="schema:publisher" typeof="schema:Organization">OpenEd CUNY </i>
                    (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2024">2024</time>).
                </li>

                {/* <!-- Citation num 6--> */}
                <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-six">
                    <span property="schema:author" typeof="schema:Person">
                        <span property="schema:Name">Sahay, G.</span>,
                        <span property="schema:Name">Alakhova, D.Y.</span>,
                        <span property="schema:Name">Kabanov, A.V. </span>
                    </span>
                    <span property="schema:name">Endocytosis of nanomedicines. </span>
                    <i property="schema:publisher" typeof="schema:Organization">Journal of Controlled Release </i>
                    <b property="issueNumber" typeof="PublicationIssue">145</b>,
                    <span property="schema:pageBegin"> 182</span>-<span property="schema:pageEnd">195 </span>
                    (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2010">2010</time>).
                    <a className="doi" href="https://doi.org/10.1016/j.jconrel.2010.01.036"> doi: 10.1016/j.jconrel.2010.01.036</a>
                </li>

                {/* <!-- Citation num 7--> */}
                <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-seven">
                    <span property="schema:author" typeof="schema:Person">
                        <span property="schema:Name">Ramachandran, S.</span>,
                        <span property="schema:Name">Satapathy, S.R.</span>,
                        <span property="schema:Name">Dutta, T. </span>
                    </span>
                    <span property="schema:name">Delivery Strategies for mRNA Vaccines. </span>
                    <i property="schema:publisher" typeof="schema:Organization">Pharmaceutical Medicine </i>
                    <b property="issueNumber" typeof="PublicationIssue">36</b>,
                    <span property="schema:pageBegin"> 11</span>-<span property="schema:pageEnd">20 </span>
                    (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2022">2022</time>).
                    <a className="doi" href="https://doi.org/10.1007/s40290-021-00417-5"> doi: 10.1007/s40290-021-00417-5</a>
                </li>

                {/* <!-- Citation num 8--> */}
                <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-eight">
                    <span property="schema:author" typeof="schema:Person">
                        <span property="schema:Name">Bandi, S.P.</span>,
                        <span property="schema:Name">Bhatnagar, S.</span>,
                        <span property="schema:Name">Venuganti, V.V.K. </span>
                    </span>
                    <span property="schema:name">Advanced materials for drug delivery across mucosal barriers. </span>
                    <i property="schema:publisher" typeof="schema:Organization">Acta Biomaterialia </i>
                    <b property="issueNumber" typeof="PublicationIssue">119</b>,
                    <span property="schema:pageBegin"> 13</span>-<span property="schema:pageEnd">29 </span>
                    (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2021">2021</time>).
                    <a className="doi" href="https://doi.org/10.1016/j.actbio.2020.10.031"> doi: 10.1016/j.actbio.2020.10.031</a>
                </li>
                {/*<!-- Citation num 9--> */}
<li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-9">
	<span property="schema:author" typeof="schema:Person">
		<span property="schema:Name"> Anzalone, A.</span>;
		<span property="schema:Name"> Randolph, P.</span>;
		<span property="schema:Name"> Davis, J.</span>;
		<span property="schema:Name"> Sousa, A.</span>;
		<span property="schema:Name"> Koblan, L.</span>;
		<span property="schema:Name"> Levy, J.</span>;
		<span property="schema:Name"> Chen, P.</span>;
		<span property="schema:Name"> Wilson, C.</span>;
		<span property="schema:Name"> Newby, G.</span>;
		<span property="schema:Name"> Raguram, A.</span>;
		<span property="schema:Name"> Liu, D.</span>
	</span>
	<span property="schema:name">&nbsp;Search-and-replace genome editing without double-strand breaks or donor DNA. </span>
	<i property="schema:publisher" typeof="schema:Organization"> Nature</i>
	<b property="issueNumber" typeof="PublicationIssue"> 576</b>,&nbsp;
	<span property="schema:pageBegin">149–157</span>
	(<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2019">2019</time>).
	<a className="doi" href="https://doi.org/10.1038/s41586-019-1711-4"> doi: 10.1038/s41586-019-1711-4</a>
</li>

{/*<!-- Citation num 10--> */}
<li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-10">
	<span property="schema:author" typeof="schema:Person">
		<span property="schema:Name"> Doman, J.</span>;
		<span property="schema:Name"> Pandey, S.</span>;
		<span property="schema:Name"> Neugebauer, M.</span>;
		<span property="schema:Name"> An, M.</span>;
		<span property="schema:Name"> Davis, J.</span>;
		<span property="schema:Name"> Randolph, P.</span>;
		<span property="schema:Name"> McElroy, A.</span>;
		<span property="schema:Name"> Gao, X.</span>;
		<span property="schema:Name"> Raguram, A.</span>;
		<span property="schema:Name"> Richter, M.</span>;
		<span property="schema:Name"> Everette, K.</span>;
		<span property="schema:Name"> Banskota, S.</span>;
		<span property="schema:Name"> Tian, K.</span>;
		<span property="schema:Name"> Tao, Y.</span>;
		<span property="schema:Name"> Tolar, J.</span>;
		<span property="schema:Name"> Osborn, M.</span>;
		<span property="schema:Name"> Liu, D.</span>
	</span>
	<span property="schema:name">&nbsp;Phage-assisted evolution and protein engineering yield compact, efficient prime editors. </span>
	<i property="schema:publisher" typeof="schema:Organization"> Cell</i>
	<b property="issueNumber" typeof="PublicationIssue"> 186</b>,&nbsp;
	<span property="schema:pageBegin"> 3983</span>-<span property="schema:pageEnd">4002.e26</span>
	(<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2023">2023</time>).
	<a className="doi" href="https://doi.org/10.1016/j.cell.2023.07.039"> doi: 10.1016/j.cell.2023.07.039</a>
</li>

{/*<!-- Citation num 11--> */}
<li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-11">
	<span property="schema:author" typeof="schema:Person">
		<span property="schema:Name"> Jinek, M.</span>;
		<span property="schema:Name"> Chylinski, K.</span>;
		<span property="schema:Name"> Fonfara, I.</span>;
		<span property="schema:Name"> Hauer, M.</span>;
		<span property="schema:Name"> Doudna, J.</span>;
		<span property="schema:Name"> Charpentier, E.</span>
	</span>
	<span property="schema:name">&nbsp;A programmable dual RNA-guided DNA endonuclease in adaptive bacterial immunity. </span>
	<i property="schema:publisher" typeof="schema:Organization"> Science (New York, N.Y.)</i>
	<b property="issueNumber" typeof="PublicationIssue"> 337</b>,&nbsp;
	<span property="schema:pageBegin">816–821</span>
	(<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2012">2012</time>).
	<a className="doi" href="https://doi.org/10.1126/science.1225829"> doi: 10.1126/science.1225829</a>
</li>

{/*<!-- Citation num 12--> */}
<li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-12">
	<span property="schema:author" typeof="schema:Person">
		<span property="schema:Name"> Nelson, J.</span>;
		<span property="schema:Name"> Randolph, P.</span>;
		<span property="schema:Name"> Shen, S.</span>;
		<span property="schema:Name"> Everette, K.</span>;
		<span property="schema:Name"> Chen, P.</span>;
		<span property="schema:Name"> Anzalone, A.</span>;
		<span property="schema:Name"> An, M.</span>;
		<span property="schema:Name"> Newby, G.</span>;
		<span property="schema:Name"> Chen, J.</span>;
		<span property="schema:Name"> Hsu, A.</span>;
		<span property="schema:Name"> Liu, D.</span>
	</span>
	<span property="schema:name">&nbsp;Engineered pegRNAs improve prime editing efficiency. </span>
	<i property="schema:publisher" typeof="schema:Organization"> Nature Biotechnology</i>
	<b property="issueNumber" typeof="PublicationIssue"> 40</b>,&nbsp;
	<span property="schema:pageBegin">402–410</span>
	(<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2022">2022</time>).
	<a className="doi" href="https://doi.org/10.1038/s41587-021-01039-7"> doi: 10.1038/s41587-021-01039-7</a>
</li>

{/*<!-- Citation num 13--> */}
<li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-13">
	<span property="schema:author" typeof="schema:Person">
		<span property="schema:Name"> Sousa, A.</span>;
		<span property="schema:Name"> Hemez, C.</span>;
		<span property="schema:Name"> Lei, L.</span>;
		<span property="schema:Name"> Traore, S.</span>;
		<span property="schema:Name"> Kulhankova, K.</span>;
		<span property="schema:Name"> Newby, G.</span>;
		<span property="schema:Name"> Doman, J.</span>;
		<span property="schema:Name"> Oye, K.</span>;
		<span property="schema:Name"> Pandey, S.</span>;
		<span property="schema:Name"> Karp, P.</span>;
		<span property="schema:Name"> McCray, P.</span>;
		<span property="schema:Name"> Liu, D.</span>
	</span>
	<span property="schema:name">&nbsp;Systematic optimization of prime editing for the efficient functional correction of CFTR F508del in human airway epithelial cells. </span>
	<i property="schema:publisher" typeof="schema:Organization"> Nature Biomedical Engineering</i>
	<b property="issueNumber" typeof="PublicationIssue"> </b>,&;
	<span property="schema:pageBegin">1–15</span>
	(<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2024">2024</time>).
	<a className="doi" href="https://doi.org/10.1038/s41551-024-01233-3"> doi: 10.1038/s41551-024-01233-3</a>
</li>
{/*<!-- Citation num 14--> */}
<li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-14">
	<span property="schema:author" typeof="schema:Person">
		<span property="schema:Name"> Rodrigues, R.</span>
	</span>
	<span property="schema:name">&nbsp;Cystic fibrosis and neonatal screening. </span>
	<i property="schema:publisher" typeof="schema:Organization"> Cadernos de Saúde Pública</i>
	<b property="issueNumber" typeof="PublicationIssue"> 24</b>,&nbsp;
	<span property="schema:pageBegin"> 475</span>-<span property="schema:pageEnd">484</span>
	(<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2008">2008</time>).
	<a className="doi" href="https://doi.org/10.1590/S0102-311X2008001600002"> doi: 10.1590/S0102-311X2008001600002</a>
</li>

{/*<!-- Citation num 15--> */}
<li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-15">
	<span property="schema:author" typeof="schema:Person">
		<span property="schema:Name"> Farrell, P.</span>
	</span>
	<span property="schema:name">&nbsp;The Impact of the CFTR Gene Discovery on Cystic Fibrosis Diagnosis, Counseling, and Preventive Therapy. </span>
	<i property="schema:publisher" typeof="schema:Organization"> Genes</i>
	<b property="issueNumber" typeof="PublicationIssue"> 11(4)</b>,&nbsp;
	<span property="schema:pageBegin">401</span>
	(<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2020">2020</time>).
	<a className="doi" href="https://doi.org/10.3390/genes11040401"> doi: 10.3390/genes11040401</a>
</li>

{/*<!-- Citation num 16--> */}
<li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-16">
	<span property="schema:author" typeof="schema:Person">
		<span property="schema:Name"> Lukacs, G.</span>
	</span>
	<span property="schema:name">&nbsp; CFTR: folding, misfolding and correcting the ΔF508 conformational defect. </span>
	<i property="schema:publisher" typeof="schema:Organization"> Trends in molecular medicine</i>
	<b property="issueNumber" typeof="PublicationIssue"> 18(2)</b>,&nbsp;
	<span property="schema:pageBegin"> 81</span>-<span property="schema:pageEnd">91</span>
	(<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2012">2012</time>).
	<a className="doi" href="https://doi.org/10.1016/j.molmed.2011.10.003"> doi: 10.1016/j.molmed.2011.10.003</a>
</li>

{/*<!-- Citation num 17--> */}
<li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-17">
	<span property="schema:author" typeof="schema:Person">
		<span property="schema:Name"> Amico, G.</span>
	</span>
	<span property="schema:name">&nbsp;Unravelling the Regions of Mutant F508del-CFTR More Susceptible to the Action of Four Cystic Fibrosis Correctors. </span>
	<i property="schema:publisher" typeof="schema:Organization"> International Journal of Molecular Sciences</i>
	<b property="issueNumber" typeof="PublicationIssue"> 20(21)</b>,&nbsp;
	<span property="schema:pageBegin">5463</span>
	(<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2019">2019</time>).
	<a className="doi" href="https://doi.org/10.3390/ijms20215463"> doi: 10.3390/ijms20215463</a>
</li>






                                
                                
                            
            </ol>
        </section>
    </div>


        </div>  
      </div>    
  );
}

 let medibuttonrowdata =[
    {
        node: <div>About</div>, 
        buttonname: "About", 
        cssname: "First"
        
    },
    {   
        node: <h2>Modulators</h2>,
        buttonname: "Modulators", 
        cssname: "modulators"
    },
    {
        node: <h2>Inhalations</h2>, 
        buttonname: "Inhalations", 
        cssname: "inhalations"
    },
]
